/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  addTeam: '创建Team',
  team: '团队',
  modifyTeam: '编辑Team',
  deleteTeam: '删除Team',
  deletePopConfirm: '确定要删除这个Team ?',
  add: '创建',
  success: '成功',
  fail: '失败',
  table: {
    title: 'Team列表',
    teamName: 'Team',
    description: '描述',
    descriptionMessage: '超过了100个字符的最大长度限制',
    teamNamePlaceholder: '请输入team名称',
    teamMessage: 'teamName至少有4个字符',
  },
};
